==> cdo_1.9.7.1.orig.tar.xz: cdo-1.9.7.1/src/fileStream.h <==
/*
  This file is part of CDO. CDO is a collection of Operators to
  manipulate and analyse Climate model Data.

  Copyright (C) 2003-2019 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
  See COPYING file for copying and redistribution conditions.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
*/

#ifndef FILESTREAM_H
#define FILESTREAM_H

#include <string>
#include "cdoStream.h"

class FileStream : public CdoStream
{
public:
  // Constructors
  FileStream(std::string p_fileStream);
  // ---

  // CdoStream Interface functions
  int openRead() override;
  int openWrite(int p_filetype) override;
  int openAppend() override;

  int inqVlist() override;
  void defVlist(int p_vlistID) override;

  void inqRecord(int *varID, int *levelID) override;
  void defRecord(int varID, int levelID) override;

  void readRecord(double *data, size_t *nmiss) override;
  void readRecord(float *data, size_t *nmiss) override;
  void writeRecord(double *data, size_t nmiss) override;
  void writeRecord(float *data, size_t nmiss) override;
  void copyRecord(CdoStreamID p_fileStream) override;

  int inqTimestep(int tsID) override;
  void defTimestep(int tsID) override;

  int inqFileType() override;
  int inqByteorder() override;

  void close() override;

  size_t getNvals() override;
  // ---

  // FileStreamOnly
  int getFileID();
  static void
  enableTimers(bool p_enable)
  {
      FileStream::TimerEnabled = p_enable;
  }
  static bool
  timersEnabled()
  {
    return FileStream::TimerEnabled;
  }
  // ---

protected:
  static bool TimerEnabled;

private:
  FileStream() = delete;
  void checkDatarange(int varID, double *array, size_t nmiss);
  std::string m_filename;
};

#endif

==> cdo_1.9.9~rc1.orig.tar.xz: cdo-1.9.9~rc1/src/fileStream.h <==
/*
  This file is part of CDO. CDO is a collection of Operators to
  manipulate and analyse Climate model Data.

  Copyright (C) 2003-2019 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
  See COPYING file for copying and redistribution conditions.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
*/

#ifndef FILESTREAM_H
#define FILESTREAM_H

#include <string>
#include "cdoStream.h"

class FileStream : public CdoStream
{
public:
  // Constructors
  FileStream(std::string p_fileStream);
  // ---

  // CdoStream Interface functions
  int openRead() override;
  int openWrite(int p_filetype) override;
  int openAppend() override;

  int inqVlist() override;
  void defVlist(int p_vlistID) override;

  void inqRecord(int *varID, int *levelID) override;
  void defRecord(int varID, int levelID) override;

  void readRecord(double *data, size_t *nmiss) override;
  void readRecord(Field *data, size_t *nmiss) override;
  void readRecord(float *data, size_t *nmiss) override;

  void writeRecord(double *data, size_t nmiss) override;
  void writeRecord(Field *data, size_t nmiss) override;
  void writeRecord(float *data, size_t nmiss) override;

  void copyRecord(CdoStreamID p_fileStream) override;

  int inqTimestep(int tsID) override;
  void defTimestep(int tsID) override;

  int inqFileType() override;
  int inqByteorder() override;

  void close() override;

  size_t getNvals() override;
  // ---

  // FileStreamOnly
  int getFileID();
  static void
  enableTimers(bool p_enable)
  {
    FileStream::TimerEnabled = p_enable;
  }
  static bool
  timersEnabled()
  {
    return FileStream::TimerEnabled;
  }
  // ---

protected:
  static bool TimerEnabled;

private:
  FileStream() = delete;
  void checkDatarange(int varID, double *array, size_t nmiss);
  std::string m_filename;
};

#endif
